@@ -2,4 +2,4 @@ from pygame_shaders import texture
 from pygame_shaders import screen_rect
 from pygame_shaders import shader_utils
 
-from pygame_shaders import pygame_shaders
\ No newline at end of file
+from pygame_shaders import Shader
\ No newline at end of file
